# pymd5search

pymd5search loops and tries to find a string which equals to itself when encoded with the md5 hash function

## install

``pip3 install pymd5search``
or
``pip install pymd5search``

## use

``pymd5search`` 
## update 

``pymd5search -u`` to update pymd5search


